@@ -1283,6 +1283,16 @@ def CN_EPU_Monthly():
     df.Date = pd.to_datetime(df.Date, format="%Y-%m-%d %H:%M:%S")
     return df
 
+def CN_Hongkong_EPU():
+    df = pd.read_excel("https://economicpolicyuncertaintyinchina.weebly.com/uploads/1/2/2/7/122762465/hkepu_1_july_2021_updated.xlsx")[:-2]
+    df.Date = pd.to_datetime(df.Date, format="%Y-%m-%d %H:%M:%S")
+    return df
+
+def CN_Macau_EPU():
+    df = pd.read_excel("https://economicpolicyuncertaintyinchina.weebly.com/uploads/1/2/2/7/122762465/mcepu_1_july_2021_updated.xlsx")[:-2]
+    df.Date = pd.to_datetime(df.Date, format="%Y-%m-%d %H:%M:%S")
+    return df
+
 def CN_EPU_Daily():
     df = pd.read_excel("https://economicpolicyuncertaintyinchina.weebly.com/uploads/1/2/2/7/122762465/cnepu_daily_7_july_2021_updated.xlsx")[:-2]
     df = df[["Date", "CNEPU_Daily"]]
@@ -1296,4 +1306,4 @@ def Policy_Specific_EPU():
 
 """
 if __name__ == "__main__":
-"""
+"""
\ No newline at end of file
